==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.2/sql/limitgroup_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists limitgroup_au//
create trigger limitgroup_au after update on limitgroup
  for each row 
begin
  insert into changeprot
    (groupID, changedtable, tableID, userID, username, action, domain, newvalues)
  select NEW.groupID, 'limitgroup', NEW.ID, coalesce(@userid,0),
    coalesce(@username,'SYSTEM'), 'update', showreg(NEW.domain, NEW.domain_v),
    concat('name=', NEW.name, '\nnotifymode=', NEW.notifymode, '\nmessage=', quotenl(NEW.message),
           '\ndestination1=', notifdestname(NEW.dest1ID),
           '\ndest1levels=', if(find_in_set('PREINFO', NEW.dest1level), 'P', ''),
             if(find_in_set('INFO', NEW.dest1level), 'I', ''),
             if(find_in_set('WARN', NEW.dest1level), 'W', ''),
             if(find_in_set('ERROR', NEW.dest1level), 'F', ''),
           '\ndestination2=', notifdestname(NEW.dest2ID),
           '\ndest2levels=', if(find_in_set('PREINFO', NEW.dest2level), 'P', ''),
             if(find_in_set('INFO', NEW.dest2level), 'I', ''),
             if(find_in_set('WARN', NEW.dest2level), 'W', ''),
             if(find_in_set('ERROR', NEW.dest2level), 'F', ''),
           '\nremark=', quotenl(NEW.remark), '\nactive=', NEW.active)
  from dual
  where NEW.TS != OLD.TS;
end//

drop trigger if exists limitgroup_ai//
create trigger limitgroup_ai after insert on limitgroup
  for each row 
begin
  insert into changeprot
    (groupID, changedtable, tableID, userID, username, action, domain, newvalues)
  values
    (NEW.groupID, 'limitgroup', NEW.ID, coalesce(@userid,0),
     coalesce(@username,'SYSTEM'), 'insert', showreg(NEW.domain, NEW.domain_v),
     concat('name=', NEW.name, '\nnotifymode=', NEW.notifymode, '\nmessage=', quotenl(NEW.message),
           '\ndestination1=', notifdestname(NEW.dest1ID),
           '\ndest1levels=', if(find_in_set('PREINFO', NEW.dest1level), 'P', ''),
             if(find_in_set('INFO', NEW.dest1level), 'I', ''),
             if(find_in_set('WARN', NEW.dest1level), 'W', ''),
             if(find_in_set('ERROR', NEW.dest1level), 'F', ''),
           '\ndestination2=', notifdestname(NEW.dest2ID),
           '\ndest2levels=', if(find_in_set('PREINFO', NEW.dest2level), 'P', ''),
             if(find_in_set('INFO', NEW.dest2level), 'I', ''),
             if(find_in_set('WARN', NEW.dest2level), 'W', ''),
             if(find_in_set('ERROR', NEW.dest2level), 'F', ''),
           '\nremark=', quotenl(NEW.remark), '\nactive=', NEW.active));
end//


drop trigger if exists limitgroup_bd//
create trigger limitgroup_bd before delete on limitgroup
  for each row 
begin
  insert into changeprot
    (groupID, changedtable, tableID, userID, username, action, newvalues)
  values
    (OLD.groupID, 'limitgroup', OLD.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
     concat('name=', OLD.name, coalesce(concat('\nremark=', quotenl(@limitgroupremark)),'')));
end//

delimiter ;

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/limitgroup_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists limitgroup_au//
create trigger limitgroup_au after update on limitgroup
  for each row 
begin
  insert into changeprot
    (groupID, changedtable, tableID, userID, username, action, domain, newvalues)
  select NEW.groupID, 'limitgroup', NEW.ID, coalesce(@userid,0),
    coalesce(@username,'SYSTEM'), 'update', showreg(NEW.domain, NEW.domain_v),
    concat('name=', NEW.name, '\nnotifymode=', NEW.notifymode, '\nmessage=', REPLACE(REPLACE(NEW.message, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.dest1ID),
           '\ndest1levels=', if(find_in_set('PREINFO', NEW.dest1level), 'P', ''),
             if(find_in_set('INFO', NEW.dest1level), 'I', ''),
             if(find_in_set('WARN', NEW.dest1level), 'W', ''),
             if(find_in_set('ERROR', NEW.dest1level), 'F', ''),
           '\ndestination2=', notifdestname(NEW.dest2ID),
           '\ndest2levels=', if(find_in_set('PREINFO', NEW.dest2level), 'P', ''),
             if(find_in_set('INFO', NEW.dest2level), 'I', ''),
             if(find_in_set('WARN', NEW.dest2level), 'W', ''),
             if(find_in_set('ERROR', NEW.dest2level), 'F', ''),
           '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
  from limitgroup
  where limitgroup.ID = NEW.ID and NEW.TS = limitgroup.TS;
end//

drop trigger if exists limitgroup_ai//
create trigger limitgroup_ai after insert on limitgroup
  for each row 
begin
  insert into changeprot
    (groupID, changedtable, tableID, userID, username, action, domain, newvalues)
  values
    (NEW.groupID, 'limitgroup', NEW.ID, coalesce(@userid,0),
     coalesce(@username,'SYSTEM'), 'insert', showreg(NEW.domain, NEW.domain_v),
     concat('name=', NEW.name, '\nnotifymode=', NEW.notifymode, '\nmessage=', REPLACE(REPLACE(NEW.message, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.dest1ID),
           '\ndest1levels=', if(find_in_set('PREINFO', NEW.dest1level), 'P', ''),
             if(find_in_set('INFO', NEW.dest1level), 'I', ''),
             if(find_in_set('WARN', NEW.dest1level), 'W', ''),
             if(find_in_set('ERROR', NEW.dest1level), 'F', ''),
           '\ndestination2=', notifdestname(NEW.dest2ID),
           '\ndest2levels=', if(find_in_set('PREINFO', NEW.dest2level), 'P', ''),
             if(find_in_set('INFO', NEW.dest2level), 'I', ''),
             if(find_in_set('WARN', NEW.dest2level), 'W', ''),
             if(find_in_set('ERROR', NEW.dest2level), 'F', ''),
           '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active));
end//


drop trigger if exists limitgroup_bd//
create trigger limitgroup_bd before delete on limitgroup
  for each row 
begin
  insert into changeprot
    (groupID, changedtable, tableID, userID, username, action, newvalues)
  values
    (OLD.groupID, 'limitgroup', OLD.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
     concat('name=', OLD.name, coalesce(concat('\nremark=', REPLACE(REPLACE(@limitgroupremark, '\\', '\\\\'), '\n', '\\n')),'')));
end//

delimiter ;
